class SecrettingError(Exception):
    """Secretting error. Yeah."""
    def __init__(self, msg, *args, **kwds):
        super().__init__(msg, *args, **kwds)
class ChaosEngineError(Exception):
    def __init__(self, msg, *args, **kwds):
        super().__init__(msg, *args, **kwds)
class AccessDeniedError(Exception):
    def __init__(self, msg, *args, **kwds):
        super().__init__(msg, *args, **kwds)
        
